ad_library {
  Server startup initialization code for the acs-automated-testing package

  @author Peter Marklund
  @creation-date 4:th of April 2003
  @cvs-id $Id: aa-test-init.tcl,v 1.2.26.1 2015/09/10 08:21:13 gustafn Exp $
}

# LARS: Moved to aa-test-procs.tcl file. See comment there.

# Local variables:
#    mode: tcl
#    tcl-indent-level: 4
#    indent-tabs-mode: nil
# End:
